Sati
====
Statistical analysis of Topographic Image

This package provides

* subtracting background (a polynomial surface, logarithmic decays, exponential decays)
* labeling terraces
* estimating terrace heights
* estimating a unit height of steps

The subtraction is possible even in the presence of steps.

Install
-------
You can install the package from the git repogitory using ``pip``
::

  $ pip install sati

Requirements
------------
Sati requires the following dependencies:

* python 3.8
* matplotlib
* numexpr
* numpy
* scipy

Documents
---------
The usage examples and the API documentation are available at https://yuksk.github.io/sati/index.html


